# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vaxa_plotly_branding']

package_data = \
{'': ['*']}

install_requires = \
['plotly>=5.13.1,<6.0.0']

setup_kwargs = {
    'name': 'vaxa-plotly-branding',
    'version': '0.1.0',
    'description': '',
    'long_description': 'Automatically brands Plotly charts with Vaxa Analytics branding.',
    'author': 'Curtis West',
    'author_email': 'curtis@curtiswest.net',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import pathlib

import plotly.graph_objects as go
import plotly.express as px
import plotly.io as pio
from PIL import Image

_colorway = px.colors.qualitative.G10
_colorway[2] = '#FBAA36'
_colorway[5] = '#00A7B5'

logo_path = pathlib.Path(__file__).parent / 'vaxa_analytics_plot_logo.png'

# noinspection PyTypeChecker
VaxaBrandingTemplate = go.layout.Template(
    layout=go.Layout(
        title_font=dict(family="Darker Grotesque", size=36),
        width=1200,
        height=800,
        font=dict(family="Plus Jakarta Sans", size=14),
        colorway=_colorway,
        yaxis_automargin='left+top',
        xaxis_automargin='left+right',
        margin=dict(b=100, pad=10),
        images=[
            dict(
                name='logo',
                source=Image.open(logo_path),
                xref="paper", yref="paper",
                x=-0.05, y=-0.1,
                sizex=0.4, sizey=0.4,
                xanchor="left", yanchor="top"
            )
        ],

        # legend settings
        showlegend=True,
        legend_title="Legend",
        legend_bgcolor = 'rgba(230,231,232,0.5)'
    ),
)
pio.templates["vaxa_analytics"] = VaxaBrandingTemplate